% GETSTRUCTDATA.M will extract selected data variables from a struct, and
% clean up the workspace when done.  This was adapted from LOADLOGDATA.M,
% which was written to manipulate log data from the RiSE robot logger.
% This function should be called by VIDSYNC_Rxx.M once the data has been
% loaded.
% A. McClung - 05/10/05 - Stanford University
% 04/28/06 - Revised specifically to use SWRI forces for plots 
%           (traction, normal, lateral)

%Make sure the file contains a 'data' structure
if isstruct(data2sync.data)==0
    error(['NOTE: ''data'' structure is not in ''' aname '''.'])
end
data=data2sync.data;
%These are the desired data fields for SWRI data
fieldname1='Leg_traction_force';
fieldname2='Leg_normal_force';
fieldname3='Leg_lateral_force';

%Get all the field names from struct data and put into convenient variables
fieldlist=fieldnames(data);
varlist=[];
for i=1:size(fieldlist,1)
    %Create variable name and place data within by converting the cell name to single matrix
    eval([cell2mat(fieldlist(i,:)) '=[data.' cell2mat(fieldlist(i,:)) ']'';'])
    varlist=[varlist ',fieldlist(' num2str(i) ',:)'];
end
%Check for the necessary force data
if exist(fieldname1)==0
    error(['''' fieldname1 ''' data is not present!'])
end
if exist(fieldname2)==0
    error(['''' fieldname2 ''' data is not present!'])
end
if exist(fieldname3)==0
    error(['''' fieldname3 ''' data is not present!'])
end

%Free up some memory and keep the desired data
clear data2sync
eval(['data2sync.trac=' fieldname1 ';'])
eval(['data2sync.norm=' fieldname2 ';'])
eval(['data2sync.late=' fieldname3 ';'])
    
%Determine the approximate sampling rate
datatime=time;                      %Copy the time data to another variable
gapsum=0;
for i=1:size(datatime,1)-1
    gapsum=gapsum+datatime(i+1)-datatime(i);
end
datasamp=size(datatime,1)/gapsum;    % Approximate sampling rate

%Cleanup the workspace
% close(flld)
for i=1:size(fieldlist,1)
    eval(['clear ' cell2mat(fieldlist(i,:))])
end
clear data fieldlist varlist prefix suffix evalstring field2plot
clear fieldname flld gapsum i fieldname*
