function varargout = vidsync_vidgui(varargin)
%VIDSYNC_VIDGUI will control a gui to select the video and data frames to
%begin  syncronizing from.  The script takes two inputs for video frames
%and data frames, and returns two numbers corresponding to the frame to
%start syncronizing from.  The user can visually scroll thru video and data
%frames to select which ones to sync.
%This function takes in video frames, data, data sampling rate, and the
%path to the movie file.  The output is a movie frame and data frame which
%represent where the two sets correspond, and a variable for performing a
%shortened time synctronization (time range, which set to use for time, etc).
%USE: [movframe1 dataframe1 tsyncinfo]=vidsync_vidgui(mov2sync,data2sync,datasamp,[vpath vfile]);
% 04/30/05 - A. McClung - Stanford University (1st stable version)
% 04/28/06 - Revised specifically to use SWRI forces for plots 
%           (traction, normal, lateral)

% VIDSYNC_VIDGUI M-file for vidsync_vidgui.fig
%      VIDSYNC_VIDGUI, by itself, creates a new VIDSYNC_VIDGUI or raises the existing
%      singleton*.
%
%      H = VIDSYNC_VIDGUI returns the handle to a new VIDSYNC_VIDGUI or the handle to
%      the existing singleton*.
%
%      VIDSYNC_VIDGUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in VIDSYNC_VIDGUI.M with the given input arguments.
%
%      VIDSYNC_VIDGUI('Property','Value',...) creates a new VIDSYNC_VIDGUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before vidsync_vidgui_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to vidsync_vidgui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES
% Copyright 2002-2003 The MathWorks, Inc.
% Last Modified by GUIDE v2.5 27-Apr-2006 20:37:43
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @vidsync_vidgui_OpeningFcn, ...
                   'gui_OutputFcn',  @vidsync_vidgui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before vidsync_vidgui is made visible.
function vidsync_vidgui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to vidsync_vidgui (see VARARGIN)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Variables that may need to be changed with video & data properties
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%NOTE: Some of these initial variables are set in both VIDSYNC_Rxx.M and VIDSYNC_VIDGUI.M, so be sure to change both.

%Get the input data
mov=varargin{1};                % The movie(video) frames
data=varargin{2};               % The data frames
datasamp=varargin{3};           % The data sampling rate
path2file=varargin{4};          % The path to the VIDEO file

%Useful variables
datacols=[1 2 3 4 5 6];         % Columns containing data for plotting
vidPos=[.1 .4 .8 .8];           % Video position and sizing
arraysize=12;                   % Size of the array to be shared by video and data (12 for 6x2 array of SWRI plots)
                                % NOTE: The array size affects where plots fall relative to the controls
axType='Force';                 % Type of data
axYUnits='[N]';                 % Units for axis
axcolor='bgrcmk';               % Colors for data plots
time=[1:size(data.trac,1)]/datasamp';        % Create the time string for data plotting
VideoOffset=1;                  % Where the 1st video frame in memory is in the actual video file
vidinfo=aviinfo(path2file);     % Structure with video info
LastFrame=vidinfo.NumFrames;    % Number of the last frame of video in file
legord='031425';                % Sequential ordered leg numbers for leg plots


%Prep the GUI w/data from the 1st frame
%Draw the 1st picture
figure(handles.figure1);
handles.VideoPlot=subplot(arraysize,1,1);       % Adjust array size for differet data
handles.VideoAxis=image(mov(1).cdata);  % Plot a frame of video
axis image off;                         % Correctly size the image
%Plot the data (6 force signals)
for i=datacols(1):datacols(1)+size(datacols,2)-1
    %Plot each column of data 
    eval(['h' num2str(i) '=subplot(' num2str(arraysize/2) ',2,' num2str(i+6) ');'])
    eval(['plot(time,data.trac(:,' num2str(datacols(1+i-datacols(1))) '),''' axcolor(1) ''');'])
    hold on
    eval(['plot(time,data.norm(:,' num2str(datacols(1+i-datacols(1))) '),''' axcolor(2) ''');'])
    eval(['plot(time,data.late(:,' num2str(datacols(1+i-datacols(1))) '),''' axcolor(3) ''');'])
    %Format the data plot
    axis tight; hold on; ylabel([axType ' ' axYUnits]); curaxis=axis;
    eval(['title(''Leg #' legord(i) ''')'])
    grid on;
    %Add the vertical time bar and store handle
    eval(['handles.Bar' num2str(i) '=plot([0 0],[-3e3 3e3],''k'',''LineWidth'',2);'])
    %Restore the axis
    axis(curaxis);
    %Get the current sizing and position of each axis
    eval(['h' num2str(i) 'Pos=get(h' num2str(i) ',''Position'');'])
    %Add a (too big) legend to one data plot
    if i==datacols(1)
        hL=legend('Traction','Normal','Lateral',0);
        set(hL,'FontSize',5)
    end
end
%Resize the video plot - this works better after all subplots are created
set(handles.VideoPlot,'Position',vidPos);
%Set the default time sync for video
set(handles.VideoButton,'Value',1);

%SLOPPY - Reposition the data plots
%vertdatapos=[.4 .28 .16];               % Vertical positioning of the data plots
                                        % NOTE: Adjust for different # data cols
%for i=datacols(1):datacols(1)+size(datacols,2)-1
%    eval(['set(h' num2str(i) ',''Position'',[h' num2str(i) 'Pos(1) ' ...
%        num2str(vertdatapos(1+i-datacols(1))) ' h' num2str(i) 'Pos(3:4)]);'])
%end

%Enter some personal variables into the handles structure
handles.MyVars.DMaxFrame=length(data.trac);  % Number of data frames
handles.MyVars.VMaxFrame=size(mov,2);   % Number of video frames
handles.mov=mov;                        % Video frames
handles.data=data;                      % Data frames
handles.vidPos=vidPos;                  % Video position and sizing
handles.arraysize=arraysize;            % Size of the array for video, control and data
handles.datasamp=datasamp;              % Sampling rate of the data
handles.path2file=path2file;            % Path to the video file
handles.LastFrame=LastFrame;            %Last frame of video file
handles.VideoOffset=VideoOffset;        %Where the 1st video frame in memory is in actual video file
% Choose default command line output for vidsync_vidgui
handles.output = hObject;
% Update handles structure
guidata(hObject, handles);
% UIWAIT makes vidsync_vidgui wait for user response (see UIRESUME)
uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = vidsync_vidgui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Place the desired outputs in the output variable
varargout{1} = str2double(get(handles.VFrameNo,'String'));  %Output 1st video frame
varargout{2} = str2double(get(handles.DFrameNo,'String'));  %Output 1st data frame
%Output the start and stop times and whether video time should be used (data time is use if not)
varargout{3} = [get(handles.TimedSyncBox,'Value') str2double(get(handles.TimedSyncStart,'String')) ...
    str2double(get(handles.TimedSyncStop,'String')) get(handles.VideoButton,'Value')];
close;          %Close the figure


%***********************************************************%
%***********************************************************%
%***************       VIDEO SECTION       *****************%
%***********************************************************%
%***********************************************************%
%NOTE: VFRAMENO is the array numbering for the video frames
%NOTE: VIDEOOFFSET+VFRAMENO is the frame number in the actual video file

% --- Executes on button press in VBackBut.
function VBackBut_Callback(hObject, eventdata, handles)
% hObject    handle to VBackBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
VFrameNo=str2double(get(handles.VFrameNo,'String'));
VideoOffset=handles.VideoOffset;    
vidPos=handles.vidPos;
arraysize=handles.arraysize;
%Check for valid frame and update video frame
if (VFrameNo>1+VideoOffset)
    VFrameNo=VFrameNo-1;
    %SLOPPY - Update the video frame and reposition the video plots
    handles.VideoPlot=subplot(arraysize,1,1,'Position',vidPos);
    handles.VideoAxis=image(handles.mov(VFrameNo-VideoOffset+1).cdata);
    axis image off;
    %Store the updated variables back in the handles structure
    set(handles.VFrameNo,'String',num2str(VFrameNo));
end
% Update handles structure
guidata(hObject, handles);

% --- Executes on button press in ForwardBut.
function VForwardBut_Callback(hObject, eventdata, handles)
% hObject    handle to ForwardBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
VFrameNo=str2double(get(handles.VFrameNo,'String'));
VideoOffset=handles.VideoOffset;
vidPos=handles.vidPos;
arraysize=handles.arraysize;
%Check for valid frame and update video frame
if (VFrameNo<handles.MyVars.VMaxFrame+VideoOffset)
    VFrameNo=VFrameNo+1;
    %SLOPPY - Update the video frame and reposition the video plots
    handles.VideoPlot=subplot(arraysize,1,1,'Position',vidPos);
    handles.VideoAxis=image(handles.mov(VFrameNo-VideoOffset+1).cdata);
    axis image off;
    %Store the updated variables back in the handles structure
    set(handles.VFrameNo,'String',num2str(VFrameNo));
end
% Update handles structure
guidata(hObject, handles);

function VFrameNo_Callback(hObject, eventdata, handles)
% hObject    handle to VFrameNo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of VFrameNo as text
%        str2double(get(hObject,'String')) returns contents of VFrameNo as a double

%Create easy to use variables
VMaxFrame=handles.MyVars.VMaxFrame;
VFrameNo=str2double(get(handles.VFrameNo,'String'));
VideoOffset=handles.VideoOffset;
vidPos=handles.vidPos;
arraysize=handles.arraysize;
%Check for valid frame and update video frame
if (VFrameNo<VideoOffset)
    VFrameNo=VideoOffset;
else if (VFrameNo>VMaxFrame+VideoOffset)
        VFrameNo=VMaxFrame+VideoOffset;
    end
end
%SLOPPY - Update the video frame and reposition the video plots
handles.VideoPlot=subplot(arraysize,1,1,'Position',vidPos);
handles.VideoAxis=image(handles.mov(VFrameNo-VideoOffset+1).cdata);
axis image off;
%Store the updated variables back in the handles structure
set(handles.VFrameNo,'String',num2str(VFrameNo));

% Update handles structure
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function VFrameNo_CreateFcn(hObject, eventdata, handles)
% hObject    handle to VFrameNo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function VJumpNum_Callback(hObject, eventdata, handles)
% hObject    handle to VJumpNum (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of VJumpNum as text
%        str2double(get(hObject,'String')) returns contents of VJumpNum as a double


% --- Executes during object creation, after setting all properties.
function VJumpNum_CreateFcn(hObject, eventdata, handles)
% hObject    handle to VJumpNum (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in VJumpBut.
function VJumpBut_Callback(hObject, eventdata, handles)
% hObject    handle to VJumpBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%Create easy to use variables
VMaxFrame=handles.MyVars.VMaxFrame;
VFrameNo=str2double(get(handles.VFrameNo,'String'));
VideoOffset=handles.VideoOffset;
vidPos=handles.vidPos;
VJumpNum=str2double(get(handles.VJumpNum,'String'));
arraysize=handles.arraysize;
%Check for valid frame and update video frame
VFrameNo=VFrameNo+VJumpNum;
if (VFrameNo<VideoOffset)
    VFrameNo=VideoOffset;
end
if (VFrameNo>VMaxFrame+VideoOffset)
    VFrameNo=VMaxFrame+VideoOffset;
end
%SLOPPY - Update the video frame and reposition the video plots
handles.VideoPlot=subplot(arraysize,1,1,'Position',vidPos);
handles.VideoAxis=image(handles.mov(VFrameNo-VideoOffset+1).cdata);
axis image off;
%Store the updated variables back in the handles structure
set(handles.VFrameNo,'String',num2str(VFrameNo));
set(handles.VJumpNum,'String','0');

% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in LoadMoreButton.
function LoadMoreButton_Callback(hObject, eventdata, handles)
% hObject    handle to LoadMoreButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
BlockSize=handles.MyVars.VMaxFrame;
LastFrame=handles.LastFrame;
%Get the frame to start loaded new data from
loadFramesFrom=LoadMoreVideo(BlockSize,LastFrame);
handles.VideoOffset=loadFramesFrom;     %Update the video offset for loaded data

%Load new video frames
frames2load=loadFramesFrom:min(LastFrame,loadFramesFrom+BlockSize);
fprintf('Loading frames [%d:%d] ....\n',frames2load(1),frames2load(size(frames2load,2)));
mov=MYaviread([handles.path2file],frames2load);

%Free up some memory
clear handles.mov
handles.mov=mov;

%Update the video frame
vidPos=handles.vidPos;
arraysize=handles.arraysize;
VFrameNo=loadFramesFrom;
%SLOPPY - Update the video frame and reposition the video plots
handles.VideoPlot=subplot(arraysize,1,1,'Position',vidPos);
handles.VideoAxis=image(handles.mov(VFrameNo-loadFramesFrom+1).cdata);
axis image off;
%Store the updated variables back in the handles structure
set(handles.VFrameNo,'String',num2str(VFrameNo));

% Update handles structure
guidata(hObject, handles);



%***********************************************************%
%***********************************************************%
%*************       DATA SECTION       ********************%
%***********************************************************%
%***********************************************************%

% --- Executes on button press in DBackBut.
function DBackBut_Callback(hObject, eventdata, handles)
% hObject    handle to DBackBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
DFrameNo=str2double(get(handles.DFrameNo,'String'));
%Check for valid frame and update vertical data time bar
if (DFrameNo>101)
    DFrameNo=DFrameNo-100;
    for i=1:6
        %Reposition vertical time bar in all data plots
        eval(['set(handles.Bar' num2str(i) ',''XData'',[DFrameNo DFrameNo]/handles.datasamp);'])
    end
    %Store the updated variables back in the handles structure
    set(handles.DFrameNo,'String',num2str(DFrameNo));
end
% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in DForwardBut.
function DForwardBut_Callback(hObject, eventdata, handles)
% hObject    handle to DForwardBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
DMaxFrame=handles.MyVars.DMaxFrame;
DFrameNo=str2double(get(handles.DFrameNo,'String'));
%Check for valid frame and update vertical data time bar
if (DFrameNo<DMaxFrame-99)
    DFrameNo=DFrameNo+100;
    for i=1:6
        %Reposition vertical time bar in all data plots
        eval(['set(handles.Bar' num2str(i) ',''XData'',[DFrameNo DFrameNo]/handles.datasamp);'])
    end
    %Store the updated variables back in the handles structure
    set(handles.DFrameNo,'String',num2str(DFrameNo));
end
% Update handles structure
guidata(hObject, handles);


function DFrameNo_Callback(hObject, eventdata, handles)
% hObject    handle to DFrameNo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of DFrameNo as text
%        str2double(get(hObject,'String')) returns contents of DFrameNo as a double

%Create easy to use variables
DMaxFrame=handles.MyVars.DMaxFrame;
DFrameNo=str2double(get(handles.DFrameNo,'String'));
%Check for valid frame and update vertical data time bar
if (DFrameNo<1)
    DFrameNo=1;
else if (DFrameNo>DMaxFrame)
        DFrameNo=DMaxFrame;
    end
end
%Reposition vertical time bar in all data plots
for i=1:6
    eval(['set(handles.Bar' num2str(i) ',''XData'',[DFrameNo DFrameNo]/handles.datasamp);'])
end
%Store the updated variables back in the handles structure
set(handles.DFrameNo,'String',num2str(DFrameNo));
% Update handles structure
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function DFrameNo_CreateFcn(hObject, eventdata, handles)
% hObject    handle to DFrameNo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function DJumpNum_Callback(hObject, eventdata, handles)
% hObject    handle to DJumpNum (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of DJumpNum as text
%        str2double(get(hObject,'String')) returns contents of DJumpNum as a double


% --- Executes during object creation, after setting all properties.
function DJumpNum_CreateFcn(hObject, eventdata, handles)
% hObject    handle to DJumpNum (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in DJumpBut.
function DJumpBut_Callback(hObject, eventdata, handles)
% hObject    handle to DJumpBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
DMaxFrame=handles.MyVars.DMaxFrame;
DFrameNo=str2double(get(handles.DFrameNo,'String'));
DJumpNum=str2double(get(handles.DJumpNum,'String'));
%Check for valid frame and update vertical data time bar
DFrameNo=DFrameNo+DJumpNum;
if (DFrameNo<1)
    DFrameNo=1;
end
if (DFrameNo>DMaxFrame)
    DFrameNo=DMaxFrame;
end
for i=1:6
    %Reposition vertical time bar in all data plots
    eval(['set(handles.Bar' num2str(i) ',''XData'',[DFrameNo DFrameNo]/handles.datasamp);'])
end
%Store the updated variables back in the handles structure
set(handles.DFrameNo,'String',num2str(DFrameNo));
set(handles.DJumpNum,'String','0');
% Update handles structure
guidata(hObject, handles);




%***********************************************************%
%***********************************************************%
%*************   TIMED SYNC SECTION       ******************%
%***********************************************************%
%***********************************************************%


% --- Executes on button press in TimedSyncBox.
function TimedSyncBox_Callback(hObject, eventdata, handles)
% hObject    handle to TimedSyncBox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


function TimedSyncStart_Callback(hObject, eventdata, handles)
% hObject    handle to TimedSyncStart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
startTime=str2double(get(handles.TimedSyncStart,'String'));
%Make sure time is valid (non-negative)
if startTime<0
    startTime=0;
end
set(handles.TimedSyncStart,'String',num2str(startTime));
% Update handles structure
guidata(hObject, handles);

% --- Executes during object creation, after setting all properties.
function TimedSyncStart_CreateFcn(hObject, eventdata, handles)
% hObject    handle to TimedSyncStart (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function TimedSyncStop_Callback(hObject, eventdata, handles)
% hObject    handle to TimedSyncStop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
stopTime=str2double(get(handles.TimedSyncStop,'String'));
VButton=get(handles.VideoButton,'Value');
LastFrame=handles.LastFrame;
LastData=size(handles.data.trac,1);
vframerate=30;          %NOTE: ASSUMMING A 30fps (standard) FRAMERATE
%Find the max time based on radio button selected (video or data)
if VButton==1
    maxTime=LastFrame/vframerate;
else
    maxTime=LastData/handles.datasamp;
end
%Make sure time is valid (non-negative)
if stopTime>maxTime
    stopTime=maxTime;
end
set(handles.TimedSyncStop,'String',num2str(stopTime,'%4.2f'));
% Update handles structure
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function TimedSyncStop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to TimedSyncStop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in VideoButton.
function VideoButton_Callback(hObject, eventdata, handles)
% hObject    handle to VideoButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
VButton=get(handles.VideoButton,'Value');
stopTime=str2double(get(handles.TimedSyncStop,'String'));
LastFrame=handles.LastFrame;
LastData=size(handles.data.trac,1);
vframerate=30;          %NOTE: ASSUMMING A 30fps (standard) FRAMERATE
%Toggle video and data radio buttons
if VButton==1
    set(handles.DataButton,'Value',0);
end

%Make sure the stop time is still good
%Find the max time based on radio button selected (video or data)
if VButton==1
    maxTime=LastFrame/vframerate;
else
    maxTime=LastData/handles.datasamp;
end
%Make sure time is valid (non-negative)
if stopTime>maxTime
    stopTime=maxTime;
end
set(handles.TimedSyncStop,'String',num2str(stopTime,'%4.2f'));

% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in DataButton.
function DataButton_Callback(hObject, eventdata, handles)
% hObject    handle to DataButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%Create easy to use variables
DButton=get(handles.DataButton,'Value');
stopTime=str2double(get(handles.TimedSyncStop,'String'));
LastFrame=handles.LastFrame;
LastData=size(handles.data.trac,1);
vframerate=30;          %NOTE: ASSUMMING A 30fps (standard) FRAMERATE
%Toggle video and data radio buttons
if DButton==1
    set(handles.VideoButton,'Value',0);
end

%Make sure the stop time is still good
%Find the max time based on radio button selected (video or data)
if DButton==0
    maxTime=LastFrame/vframerate;
else
    maxTime=LastData/handles.datasamp;
end
%Make sure time is valid (non-negative)
if stopTime>maxTime
    stopTime=maxTime;
end
set(handles.TimedSyncStop,'String',num2str(stopTime,'%4.2f'));

% Update handles structure
guidata(hObject, handles);


%***********************************************************%
%***********************************************************%
%*************     EXTRAS SECTION       ********************%
%***********************************************************%
%***********************************************************%

% --------------------------------------------------------------------
function Untitled_1_Callback(hObject, eventdata, handles)
% hObject    handle to Untitled_1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in DoneBut.
function DoneBut_Callback(hObject, eventdata, handles)
% hObject    handle to DoneBut (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%NOTE: This is needed to resume the terminate the opening function execution
% (vidsync_vidgui_OpeningFcn) and run the closing function (vidsync_vidgui_OutputFcn)
% so that the main function (VIDSYNC_VIDGUI) can conclude
uiresume;
